﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ATOUCHX;

namespace atouch_p10_en_02
{
    public partial class Form1 : Form
    {
        //Delegates declaration for communication between threads.
        private delegate void DelEndPutData(int WID, int Result, int Param);
        private delegate void DelEndGetData(int WID, int Result, int Param, object DATA);

        //Necessary objects and variables definition.
        AtouchApp App = new AtouchApp();
        int Err;

        public Form1()
        {
            InitializeComponent();
            //After-communication event handlers initialization. When App.xxx += is writed and then 
            //the Tab key is double pressed, the event code block is created automatically.
            App.EndNetGetData += new _IAtouchAppEvents_EndNetGetDataEventHandler(App_EndNetGetData);
            App.EndNetPutData += new _IAtouchAppEvents_EndNetPutDataEventHandler(App_EndNetPutData);
        }

        void App_EndNetPutData(int WID, int Result, int Param)
        {
            if (this.InvokeRequired)
            {
                //The code is running in a different thread than in the UI thread. Therefore it is necessary
                //to use the Invoke method for thread-safe call on form controls.
                this.Invoke(new DelEndPutData(App_EndNetPutData), new Object[] { WID, Result, Param });
                return;
            }
            //The code is running in the UI thread here and it is possible to call on form controls.
            //Call on a form control after a write request execution.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Communication ended OK.
                ComText.Text = "OK";
            }
            else
            {   //Communication ended with error. 
                ComText.Text = Result.ToString();
            }
        }

        void App_EndNetGetData(int WID, int Result, int Param, object DATA)
        {
            if (this.InvokeRequired)
            {
                //The code is running in a different thread than in the UI thread. Therefore it is necessary
                //to use the Invoke method for thread-safe call on form controls.
                this.Invoke(new DelEndGetData(App_EndNetGetData), new Object[] { WID, Result, Param, DATA });
                return;
            }
            //The code is running in the UI thread here and it is possible to call on form controls.
            //Call on a form control after a matrix-read request execution.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Communication ended OK.
                ComText.Text = "OK";
                switch (Param)
                {
                    case 1:
                        Int16[,] iarr = (Int16[,])DATA;
                        M11IW.Text = iarr[0, 0].ToString();
                        M12IW.Text = iarr[0, 1].ToString();
                        M13IW.Text = iarr[0, 2].ToString();
                        M14IW.Text = iarr[0, 3].ToString();
                        M15IW.Text = iarr[0, 4].ToString();
                        break;
                    case 2:
                        Int32[,] larr = (Int32[,])DATA;
                        M11LW.Text = larr[0, 0].ToString();
                        M12LW.Text = larr[0, 1].ToString();
                        M21LW.Text = larr[1, 0].ToString();
                        M22LW.Text = larr[1, 0].ToString();
                        break;
                    case 3:
                        Single[,] farr = (Single[,])DATA;
                        M11FW.Text = farr[0, 0].ToString();
                        M21FW.Text = farr[1, 0].ToString();
                        M31FW.Text = farr[2, 0].ToString();
                        M41FW.Text = farr[3, 0].ToString();
                        break;
                }
            }
            else
            {   //Communication ended with error.
                ComText.Text = Result.ToString();
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Initialization method for DB-net network communication.
            Err = App.InitFromFile("hw.ini", "db.ini");
            App.VariantOnly = false;
            ErrText.Text = Err.ToString();
        }

        //DB-Net network communication termination.
        private void EndProg_Click(object sender, EventArgs e)
        {
            App.Done();
            this.Close();
        }

        //Matrix variables reading from a control system.
        private void ReadIntMX_Click(object sender, EventArgs e)
        {
            Err = App.NetGetDataMtx(1002, 0, 0, 1, 5, 1);
            ErrText.Text = Err.ToString();
        }

        private void ReadLonMX_Click(object sender, EventArgs e)
        {
            Err = App.NetGetDataMtx(1004, 0, 0, 2, 2, 2);
            ErrText.Text = Err.ToString();
        }

        private void ReadFloMX_Click(object sender, EventArgs e)
        {
            Err = App.NetGetDataMtx(1006, 0, 0, 4, 1, 3);
            ErrText.Text = Err.ToString();
        }

        //Matrix variables writing to a control system:
        private void WriteIntMX_Click(object sender, EventArgs e)
        {   //The Int type in a control system has length of 2B, therefore the value must me converted to the C# Int16 type.
            object[,] Data = new object[1, 5];
            Data[0, 0] = Convert.ToInt16(M11I.Text);
            Data[0, 1] = Convert.ToInt16(M12I.Text);
            Data[0, 2] = Convert.ToInt16(M13I.Text);
            Data[0, 3] = Convert.ToInt16(M14I.Text);
            Data[0, 4] = Convert.ToInt16(M15I.Text);
            Err = App.NetPutDataMtx(1002, 0, 0, 1, 5, 1, Data);
            ErrText.Text = Err.ToString();
        }

        private void WriteLonMX_Click(object sender, EventArgs e)
        {
            object[,] Data = new object[2, 2];
            Data[0, 0] = Convert.ToInt32(M11L.Text);
            Data[0, 1] = Convert.ToInt32(M12L.Text);
            Data[1, 0] = Convert.ToInt32(M21L.Text);
            Data[1, 1] = Convert.ToInt32(M22L.Text);
            Err = App.NetPutDataMtx(1004, 0, 0, 2, 2, 2, Data);
            ErrText.Text = Err.ToString();
        }

        private void WriteFloMX_Click(object sender, EventArgs e)
        {
            object[,] Data = new object[4, 1];
            Data[0, 0] = Convert.ToSingle(M11F.Text);
            Data[1, 0] = Convert.ToSingle(M21F.Text);
            Data[2, 0] = Convert.ToSingle(M31F.Text);
            Data[3, 0] = Convert.ToSingle(M41F.Text);
            Err = App.NetPutDataMtx(1006, 0, 0, 4, 1, 3, Data);
            ErrText.Text = Err.ToString();
        }
    }
}
