﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ATOUCHX;

namespace atouch_p12_en_02
{
    public partial class Form1 : Form
    {
        //Delegate declaration for communication between threads.
        private delegate void DelSample(int AID, object DATA);

        //Necessary objects and variables definition.
        AtouchApp App = new AtouchApp();
        AtouchArch AArch = new AtouchArch();
        int Ind = 0;
        int Err;

        public Form1()
        {
            InitializeComponent();
            //After-communication event handlers initialization. When App.xxx += is writed and then 
            //the Tab key is double pressed, the event code block is created automatically.
            AArch.Sample += new _IAtouchArchEvents_SampleEventHandler(AArch_Sample);
            AArch.Completed += new _IAtouchArchEvents_CompletedEventHandler(AArch_Completed);
        }

        void AArch_Sample(int AID, object DATA)
        {
            if (this.InvokeRequired)
            {
                //The code is running in a different thread than in the UI thread. Therefore it is necessary
                //to use the Invoke method for thread-safe call on form controls.
                this.Invoke(new DelSample(AArch_Sample), new Object[] { AID, DATA });
                return;
            }
            //The code is running in the UI thread here and it is possible to call on form controls.

            String PDtext = String.Format("{0}: ", Ind++);
            if (DATA is object[])
            {
                object[] MData = (object[])DATA;
                PDtext += String.Format("\t{0}\t\t{1}\t{2}", MData[0], MData[1], MData[2]);
            }
            PDtext += "\n";
            richTextBox1.AppendText(PDtext);
            AArch.Accept(0, true);
        }

        void AArch_Completed(int AID, int Samples)
        {
            //The code is running in a different thread than in the UI thread.
            //However there is no code that works with UI, therefore Invoke metod is not needed.

            //End of automatic archive run.
            AArch.Control(0, false);
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Initialization method for DB-net network communication.
            Err = App.InitFromFile("hw.ini", "db.ini");
            if (Err == (Int16)AtouchX_Error_Code.arrOK)
            {
                //Initialization method for archive description load.
                Err = AArch.InitFromFile("PD_Arch.ini");
            }
            ErrText.Text = Err.ToString();
        }

        //DB-Net network communication termination.
        private void EndProg_Click(object sender, EventArgs e)
        {
            AArch.Done();
            App.Done();
            this.Close();
        }

        //Archive reading from control system.
        private void ReadArch_Click(object sender, EventArgs e)
        {
            richTextBox1.Text = "";
            Err = AArch.Control(0, true);
            ErrText.Text = Err.ToString();
        }
    }
}
