﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ATOUCHX;

namespace atouch_p14_en_02
{
    public partial class Form1 : Form
    {
        //Delegate declaration for communication between threads.
        private delegate void DelEndGetData(int WID, int Result, int Param, object DATA);

        //Necessary objects and variables definition.
        AtouchApp App = new AtouchApp();
        int Err;
        Object Data = new Object();

        public Form1()
        {
            InitializeComponent();
            //After-communication event handlers initialization. When App.xxx += is writed and then 
            //the Tab key is double pressed, the event code block is created automatically.
            App.EndNetGetData += new _IAtouchAppEvents_EndNetGetDataEventHandler(App_EndNetGetData);
        }

        void App_EndNetGetData(int WID, int Result, int Param, object DATA)
        {
            if (this.InvokeRequired)
            {
                //The code is running in a different thread than in the UI thread. Therefore it is necessary
                //to use the Invoke method for thread-safe call on form controls.
                this.Invoke(new DelEndGetData(App_EndNetGetData), new Object[] { WID, Result, Param, DATA });
                return;
            }
            //The code is running in the UI thread here and it is possible to call on form controls.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Communication ended OK.
                switch (Param)
                {
                    case 1:
                        CS1Text.Text = DATA.ToString();
                        break;
                    case 2:
                        CS1TextSec.Text = DATA.ToString();
                        break;
                    case 3:
                        CS2Text.Text = DATA.ToString();
                        break;
                    case 4:
                        CS2TextSec.Text = DATA.ToString();
                        break;
                }
            }
            else
            {   //Communication ended with error.
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Initialization method for DB-net network communication.
            Err = App.InitFromFile("hw.ini", "db.ini");
            App.VariantOnly = false;
            ErrText.Text = Err.ToString();
        }

        //DB-Net network communication termination.
        private void EndProg_Click(object sender, EventArgs e)
        {
            App.Done();
            this.Close();
        }
       
        //Variables reading from control system: the WID and identification parameter are sent.
        private void ReadCS1_Click(object sender, EventArgs e)
        {
            Err = App.NetGetData(1001000, 1);
            ErrText.Text = Err.ToString();
            if (Err == (Int16)AtouchX_Error_Code.arrOK)
            {
                Err = App.NetGetData(1001011, 2);
                ErrText.Text = Err.ToString();
            }
        }

        private void ReadCS2_Click(object sender, EventArgs e)
        {
            Err = App.NetGetData(2001000, 3);
            ErrText.Text = Err.ToString();
            if (Err == (Int16)AtouchX_Error_Code.arrOK)
            {
                Err = App.NetGetData(2001011, 4);
                ErrText.Text = Err.ToString();
            }
        }
    }
}